qtl2fst-package: qtl2fst: Database Storage of Genotype Probabilities for QTL...

qtl2fst-packageR Documentation

qtl2fst: Database Storage of Genotype Probabilities for QTL Mapping

Description

Uses the 'fst' package to store genotype probabilities on disk for the 'qtl2' package. These genotype probabilities are a central data object for mapping quantitative trait loci (QTL), but they can be quite large. The facilities in this package enable the genotype probabilities to be stored on disk, leading to reduced memory usage with only a modest increase in computation time.

Author(s)

Maintainer: Karl W Broman broman@wisc.edu (ORCID)

Authors:

See Also

Useful links:


qtl2fst documentation built on July 16, 2026, 5:10 p.m.